RecordingsApi class

Constructors

RecordingsApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel(String name) Future<HttpClientResponse>
copyStored(String name) Future<HttpClientResponse>
destroyStored(String name) Future<HttpClientResponse>
getLive(String name) Future<HttpClientResponse>
getStored(String name) Future<HttpClientResponse>
getStoredFile(String name) Future<HttpClientResponse>
listStored() Future<HttpClientResponse>
mute(String name) Future<HttpClientResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(String name) Future<HttpClientResponse>
stop(String name) Future<HttpClientResponse>
toString() String
A string representation of this object.
inherited
unmute(String name) Future<HttpClientResponse>
unpause(String name) Future<HttpClientResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited