ARI constructor

ARI()

Creates a new awry API instance, providing clients for all available Asterisk ARI endpoints.

@param {object} params @param {string} params.username The username to send with the request. @param {string} params.password The password to send with the request. @param {string} params.baseUrl The base url, without trailing slash, of the root Asterisk ARI endpoint. i.e. 'http://myserver.local:8088/ari'.

Implementation

ARI() {}