StasisStart class

Inheritance

Constructors

StasisStart(dynamic args, DateTime timestamp, Channel channel, dynamic json)
StasisStart.fromJson(dynamic json)
factory

Properties

args ↔ dynamic
Arguments to the application.
getter/setter pair
asterisk_id String?
The unique ID for the Asterisk instance that raised this event.
getter/setter pairinherited
channel Channel
Channel.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
json ↔ dynamic
getter/setter pair
replace_channel Channel?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
Replace_channel.
getter/setter pair
type String
Indicates the type of this message.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited