StasisEnd class
Constructors
- StasisEnd(Channel channel, DateTime timestamp, dynamic json)
- StasisEnd.fromJson(dynamic json)
-
factory
Properties
- asterisk_id ↔ String?
-
The unique ID for the Asterisk instance that raised this event.
getter/setter pairinherited
- channel ↔ Channel
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- json ↔ dynamic
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp ↔ DateTime
-
Channel.
getter/setter pair
- type ↔ String
-
Indicates the type of this message.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited